import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import React, { memo } from "react";
import classNames from "classnames";
import { styled, Tooltip } from "@material-ui/core";
import stringToSequence from "../../string-to-sequence.js";
var SequenceItemContainer = styled("span")(function (_ref) {
  var color = _ref.color,
      relationshipsOn = _ref.relationshipsOn;
  return {
    display: "inline-flex",
    cursor: "pointer",
    backgroundColor: color,
    color: "#fff",
    padding: 2,
    margin: 1,
    marginBottom: relationshipsOn ? 64 : 4,
    borderRadius: 4,
    userSelect: "none",
    boxSizing: "border-box",
    "&.unlabeled": {
      color: "#333",
      paddingTop: 4,
      paddingBottom: 4,
      paddingLeft: 1,
      paddingRight: 1,
      ".notSpace:hover": {
        paddingTop: 2,
        paddingBottom: 2,
        paddingLeft: 0,
        paddingRight: 0,
        border: "2px dashed #ccc"
      },
      "&.newLine": {
        width: "100%",
        height: 0,
        border: "none",
        margin: 0,
        padding: 0
      }
    }
  };
});
var XContainer = styled("div")({
  display: "inline-flex",
  cursor: "pointer",
  alignSelf: "center",
  fontSize: 11,
  width: 18,
  height: 18,
  alignItems: "center",
  justifyContent: "center",
  marginLeft: 4,
  borderRadius: 9,
  color: "#fff",
  backgroundColor: "rgba(0,0,0,0.2)"
});
export var SequenceItem = function SequenceItem(_ref2) {
  var _ref3;

  var textId = _ref2.textId,
      text = _ref2.text,
      label = _ref2.label,
      color = _ref2.color,
      sequenceItemIndex = _ref2.sequenceItemIndex,
      sequenceItemPositionsRef = _ref2.sequenceItemPositionsRef,
      relationshipsOn = _ref2.relationshipsOn,
      createRelationshipsMode = _ref2.createRelationshipsMode,
      onChangeFirstSequenceItem = _ref2.onChangeFirstSequenceItem,
      onChangeSecondSequenceItem = _ref2.onChangeSecondSequenceItem,
      onCreateEmptyRelationship = _ref2.onCreateEmptyRelationship,
      onChangeHighlightedRange = _ref2.onChangeHighlightedRange,
      firstSequenceItem = _ref2.firstSequenceItem,
      secondSequenceItem = _ref2.secondSequenceItem,
      mouseDown = _ref2.mouseDown,
      firstSelected = _ref2.firstSelected,
      lastSelected = _ref2.lastSelected,
      colorLabelMap = _ref2.colorLabelMap,
      isHighlighted = _ref2.isHighlighted,
      onRemoveLabel = _ref2.onRemoveLabel,
      constraintRelationships = _ref2.constraintRelationships,
      overviewMode = _ref2.overviewMode,
      _onClick = _ref2.onClick;
  return /*#__PURE__*/React.createElement(SequenceItemContainer, {
    key: textId || sequenceItemIndex,
    ref: function ref(elm) {
      if (!elm) return;
      sequenceItemPositionsRef.current[textId] = {
        offset: {
          left: elm.offsetLeft,
          top: elm.offsetTop,
          width: elm.offsetWidth,
          height: elm.offsetHeight
        }
      };
    },
    onClick: function onClick() {
      _onClick(textId);
    },
    relationshipsOn: relationshipsOn,
    onMouseUp: function onMouseUp(e) {
      if (overviewMode) {
        return;
      }

      if (!createRelationshipsMode) return;

      if (!secondSequenceItem) {
        if (!label && constraintRelationships) {
          return;
        } // remove possibility to add  relationships between sequence item without label


        onChangeFirstSequenceItem(null);
        onChangeSecondSequenceItem(null);
        onCreateEmptyRelationship([firstSequenceItem, textId]);
      } else {
        onChangeFirstSequenceItem(null);
        onChangeSecondSequenceItem(null);
      }
    },
    style: {
      position: 'relative'
    },
    onMouseDown: function onMouseDown() {
      if (overviewMode) {
        return;
      }

      if (createRelationshipsMode) {
        if (!label && constraintRelationships) {
          return;
        } // remove possibility to add  relationships between sequence item without label


        if (!firstSequenceItem) {
          onChangeFirstSequenceItem(textId);
        }
      } else {
        if (label) return;
        onChangeHighlightedRange([sequenceItemIndex, sequenceItemIndex]);
      }
    },
    onMouseMove: function onMouseMove() {
      if (overviewMode) {
        return;
      }

      if (!mouseDown) return;

      if (!createRelationshipsMode) {
        if (label) return;

        if (sequenceItemIndex !== lastSelected) {
          onChangeHighlightedRange([firstSelected === null ? sequenceItemIndex : firstSelected, sequenceItemIndex]);
        }
      }
    },
    className: classNames(label ? "label" : "unlabeled", text.trim().length > 0 && text !== '\n' && "notSpace", text.includes('\n') && "newLine"),
    color: label ? color || "#333" : !createRelationshipsMode && text !== " " && isHighlighted ? "#ccc" : "inherit"
  }, label && !overviewMode ? /*#__PURE__*/React.createElement(Tooltip, {
    title: label,
    placement: "bottom"
  }, /*#__PURE__*/React.createElement("div", null, text)) : /*#__PURE__*/React.createElement("div", null, text), overviewMode && /*#__PURE__*/React.createElement("div", {
    style: (_ref3 = {
      position: 'absolute',
      bottom: '-15px',
      left: '-1px',
      marginLeft: 'auto',
      marginRight: 'auto'
    }, _defineProperty(_ref3, "left", 0), _defineProperty(_ref3, "right", 0), _defineProperty(_ref3, "textAlign", 'center'), _defineProperty(_ref3, "color", 'black'), _defineProperty(_ref3, "fontSize", '10px'), _ref3)
  }, label), label && !createRelationshipsMode && !overviewMode && /*#__PURE__*/React.createElement(XContainer, {
    onClick: function onClick(e) {
      e.stopPropagation();
      onRemoveLabel(sequenceItemIndex);
    }
  }, /*#__PURE__*/React.createElement("span", null, "\u2716")));
};
export default memo(SequenceItem);